@@ -77,6 +77,8 @@ struct _Shape {
   double offset_x, offset_y;
   Shape *shape_place;			/* the shape place in this place */
   Shape *placed ;			/* where is placed this shape */
+  GooCanvasItem *crossitem;    	  	/* A red cross indicating the item is */
+				  	/* not at the correct position */
   };
 
 /* This is the list of shape for the current game */
@@ -128,6 +130,7 @@ static void 		 end_board (void);
 static gboolean 	 is_our_board (GcomprisBoard *gcomprisBoard);
 static void 		 set_level (guint level);
 static void 		 process_ok(void);
+static void 		 process_nok(void);
 static gint		 key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 static void	         config_start (GcomprisBoard *agcomprisBoard,
 				       GcomprisProfile *aProfile);
@@ -161,6 +164,8 @@ static void dump_shape(Shape *shape);
 #endif
 static void update_shapelist_item(void);
 static void auto_process(void);
+static void show_errors(void);
+static void hide_errors(void);
 
 static gint drag_mode;
 /* Description of this plugin */
@@ -225,7 +230,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   GHashTable *config = gc_db_get_board_conf();
 
   if (strcmp(agcomprisBoard->name, "imagename")==0){
-    gc_locale_change(g_hash_table_lookup( config, "locale"));
+    gc_locale_set(g_hash_table_lookup( config, "locale"));
   }
 
   gchar *drag_mode_str = g_hash_table_lookup( config, "drag_mode");
@@ -322,7 +327,7 @@ end_board ()
     }
 
   if (strcmp(gcomprisBoard->name, "imagename")==0){
-    gc_locale_reset();
+    gc_locale_set( NULL );
   }
 
   if (selector_item)
@@ -473,6 +478,14 @@ static void process_ok()
   g_object_set (continue_root_item, "visibility", GOO_CANVAS_ITEM_VISIBLE, NULL);
 }
 
+static void process_nok()
+{
+  gamewon = FALSE;
+
+  /* Show the tooltip to let the user continue the game */
+  g_object_set (continue_root_item, "visibility", GOO_CANVAS_ITEM_VISIBLE, NULL);
+}
+
 static void destroy_shape (Shape *shape)
 {
   g_free(shape->name);
@@ -592,17 +605,17 @@ static void shapegame_init_canvas(GooCanvasItem *parent)
 
   g_signal_connect(continue_root_item,
 		   "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "continue_click");
 
   g_signal_connect(continue_root_item,
 		   "enter_notify_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "title_raise");
 
   g_signal_connect(continue_root_item,
 		   "leave_notify_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "title_lower");
 
   /* Hide the continue */
@@ -644,7 +657,7 @@ add_shape_to_list_of_shapes(Shape *shape)
 
       g_signal_connect(previous_shapelist_item,
 		       "button_press_event",
-		       (GtkSignalFunc) item_event_ok,
+		       (GCallback) item_event_ok,
 		       "previous_shapelist");
       gc_item_focus_init(previous_shapelist_item, NULL);
 
@@ -659,7 +672,7 @@ add_shape_to_list_of_shapes(Shape *shape)
 			shapeBox.h);
 
       g_signal_connect(next_shapelist_item, "button_press_event",
-		       (GtkSignalFunc) item_event_ok,
+		       (GCallback) item_event_ok,
 		       "next_shapelist");
       gc_item_focus_init(next_shapelist_item, NULL);
 
@@ -870,6 +883,10 @@ shape_goes_back_to_list(Shape *shape)
 {
   gdouble z;
 
+  g_object_set (continue_root_item, "visibility", GOO_CANVAS_ITEM_INVISIBLE,
+		NULL);
+  hide_errors();
+
   if(shape->type == SHAPE_ICON)
     shape = shape->target_shape;
 
@@ -939,11 +956,12 @@ item_event_drag(GooCanvasItem *item,
 	{
 	case SHAPE_TARGET:
 	  /* unplace this shape */
-	  if (shape->placed && shape->placed->target_point)
+	  if (shape->placed && shape->placed->target_point) {
 	    g_object_set (shape->placed->target_point, "visibility",
 			  GOO_CANVAS_ITEM_VISIBLE, NULL);
-	  shape->placed->shape_place = NULL;
-	  shape->placed = NULL;
+	    shape->placed->shape_place = NULL;
+	    shape->placed = NULL;
+	  }
 	  /* No break on purpose */
 	case SHAPE_ICON:
 	  gc_drag_offset_save(event);
@@ -992,6 +1010,8 @@ item_event_drag(GooCanvasItem *item,
 					     NULL);
 	  g_object_set(shadow_item, "visibility",
 		       GOO_CANVAS_ITEM_INVISIBLE, NULL);
+	  g_object_set(shadow_item, "pointer-events",
+		       GOO_CANVAS_EVENTS_NONE, NULL);
 	  gdk_pixbuf_unref(dest);
 	}
       dragged = shape->item;
@@ -1186,6 +1206,7 @@ auto_process(void)
 {
   GList *list;
   gboolean done = TRUE;
+  gboolean all_placed = TRUE;
 
   /* Loop through all the shapes to find if all target are in place */
   for(list = shape_list; list != NULL; list = list->next)
@@ -1196,11 +1217,57 @@ auto_process(void)
 	{
 	  if(shape->placed != shape)
 	    done=FALSE;
+
+	  if(shape->placed == NULL)
+	    all_placed = FALSE;
 	}
     }
 
   if(done)
     process_ok();
+  else if(all_placed)
+    process_nok();
+}
+
+static void
+show_errors(void)
+{
+  GList *list;
+
+  /* Loop through all the shapes to find and highlight the error item */
+  for(list = shape_list; list != NULL; list = list->next)
+    {
+      Shape *shape = list->data;
+
+      if(shape->type == SHAPE_TARGET)
+	{
+	  if(shape->placed != shape)
+	    {
+	      g_object_set (shape->crossitem, "visibility", GOO_CANVAS_ITEM_VISIBLE, NULL);
+	      goo_canvas_item_raise(shape->crossitem, NULL);
+	    }
+	  else
+	    g_object_set (shape->crossitem, "visibility", GOO_CANVAS_ITEM_INVISIBLE, NULL);
+
+	}
+    }
+}
+
+static void
+hide_errors(void)
+{
+  GList *list;
+
+  /* Loop through all the shapes and hide the error item */
+  for(list = shape_list; list != NULL; list = list->next)
+    {
+      Shape *shape = list->data;
+
+      if(shape->type == SHAPE_TARGET)
+	{
+	  g_object_set (shape->crossitem, "visibility", GOO_CANVAS_ITEM_INVISIBLE, NULL);
+	}
+    }
 }
 
 static void
@@ -1267,8 +1334,8 @@ item_event_ok(GooCanvasItem *item, GooCanvasItem *target,
 	  update_shapelist_item();
 	}
       else if(!strcmp(data, "continue_click"))
-	if(gamewon == TRUE)
-	  gc_bonus_display(gamewon, GC_BONUS_FLOWER);
+	show_errors();
+	gc_bonus_display(gamewon, GC_BONUS_FLOWER);
 
       root_item = g_list_nth_data(shape_list_group, current_shapelistgroup_index);
       g_object_set (root_item, "visibility", GOO_CANVAS_ITEM_VISIBLE, NULL);
@@ -1302,18 +1369,18 @@ static void
 setup_item(GooCanvasItem *item, Shape *shape)
 {
   g_signal_connect(item, "enter_notify_event",
-		   (GtkSignalFunc) item_event,
+		   (GCallback) item_event,
 		   shape);
   g_signal_connect(item, "leave_notify_event",
-		   (GtkSignalFunc) item_event,
+		   (GCallback) item_event,
 		   shape);
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event,
+		   (GCallback) item_event,
 		   shape);
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) gc_drag_event, shape);
+		   (GCallback) gc_drag_event, shape);
   g_signal_connect(item, "button_release_event",
-		   (GtkSignalFunc) gc_drag_event, shape);
+		   (GCallback) gc_drag_event, shape);
 }
 
 /*
@@ -1370,7 +1437,22 @@ add_shape_to_canvas(Shape *shape)
 					 "line-width", 2.0,
 					 NULL);
 	  shape->target_point = item;
+
+	  pixmap = gc_pixmap_load("shapegame/error.svg");
+	  if(pixmap)
+	    {
+	      /* Display the error cross */
+	      shape->crossitem = \
+		goo_canvas_image_new (shape_root_item,
+				      pixmap,
+				      shape->x - gdk_pixbuf_get_width(pixmap) / 2,
+				      shape->y - gdk_pixbuf_get_height(pixmap) / 2,
+				      NULL);
+	      g_object_set (shape->crossitem,
+			    "visibility", GOO_CANVAS_ITEM_INVISIBLE, NULL);
+	    }
 	}
+
       if (item)
 	goo_canvas_item_lower(item, NULL);
     }
