@@ -107,8 +107,8 @@ static gchar *linguas[] = {
   "pa_IN.UTF-8",	N_("Punjabi"),
   "ro_RO.UTF-8",	N_("Romanian"),
   "ru_RU.UTF-8",	N_("Russian"),
-  "sr@Latn_YU.ISO-8859-2",	N_("Serbian (Latin)"),
-  "sr_YU.UTF-8",	N_("Serbian"),
+  "sr@latin_RS.UTF-8",	N_("Serbian (Latin)"),
+  "sr_RS.UTF-8",	N_("Serbian"),
   "sk_SK.UTF-8",	N_("Slovak"),
   "sl_SI.UTF-8",	N_("Slovenian"),
   "so_SO.UTF-8",	N_("Somali"),
@@ -232,7 +232,7 @@ gc_config_start ()
 			      (-1 * bounds.x1 + x_flag_start - 340) * zoom,
 			      (-1 * bounds.y1 + y_start - 120) * zoom);
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "locale_reset");
   gc_item_focus_init(item, NULL);
 
@@ -262,7 +262,7 @@ gc_config_start ()
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "fullscreen");
   gc_item_focus_init(item, NULL);
 
@@ -287,7 +287,7 @@ gc_config_start ()
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "music");
   gc_item_focus_init(item, NULL);
 
@@ -312,7 +312,7 @@ gc_config_start ()
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "effect");
   gc_item_focus_init(item, NULL);
 
@@ -337,7 +337,7 @@ gc_config_start ()
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   "zoom");
   gc_item_focus_init(item, NULL);
 
@@ -454,7 +454,7 @@ gc_config_start ()
 			  y,
 			  "#BUTTON_TEXT",
 			  _("OK"),
-			  (GtkSignalFunc) item_event_ok,
+			  (GCallback) item_event_ok,
 			  "ok");
 
   is_displayed = TRUE;
@@ -484,27 +484,109 @@ void gc_config_stop ()
 
 /**
  * Given the locale name, return the full translated name
- * If not found, simply return the name
+ * e.g In the French locale, gc_locale_get_name("fr_FR.UTF8") returns "Français"
+ * If not found, return NULL
+ * The result must not be freed.
  */
-gchar*
-gc_locale_get_name(gchar *locale)
+const gchar*
+gc_locale_get_name(const gchar *locale)
 {
   guint i = 0;
 
-  /* en (US) is not in the Linguas table */
-  if(locale[0] != '\0' && !strncmp(locale, "en", strlen(locale)))
-    return(_("English (United State)"));
+  if ( !locale )
+    return NULL;
+
+  /*
+   * On some systems, locales are returned as fr_FR.utf8
+   * but in GCompris we use fr_FR.UTF-8
+   * Do our best to support both
+   */
+  const gchar *dot_char = g_strrstr ( locale, ".");
 
   while(linguas[i] != NULL)
     {
 
-      if(!strncmp(locale, linguas[i], strlen(locale)))
+      if( !g_ascii_strncasecmp(locale, linguas[i],
+			       (dot_char ? dot_char - locale : strlen(locale)) ) )
 	return(gettext(linguas[i+1]));
 
       i=i+2;
     }
-  // Oups this locale is not in the table. Return the first one (system default)
-  return(linguas[1]);
+  // Oups this locale is not in the table.
+  return( NULL );
+}
+
+/**
+ * Given the locale code, return the short version
+ * e.g In the French locale, gc_locale_short("fr_FR.UTF8") returns "fr"
+ * The result must be freed.
+ */
+gchar*
+gc_locale_short(const gchar *locale)
+{
+  if ( ! locale )
+    return NULL;
+
+  gchar **locale_short = g_strsplit_set(locale, "_", 2);
+  if(g_strv_length(locale_short) >= 1)
+    {
+      gchar *result = g_strdup(locale_short[0]);
+      g_strfreev(locale_short);
+      return result;
+    }
+  g_strfreev(locale_short);
+
+  // We found no '_', this is already a short version
+  return ( g_strdup(locale) );
+}
+
+/**
+ * Given the locale code, return the long version
+ * e.g In the French locale, gc_locale_long("fr_FR.UTF8") returns "fr_FR"
+ * The result must be freed.
+ */
+gchar*
+gc_locale_long(const gchar *locale)
+{
+  if ( ! locale )
+    return NULL;
+
+  gchar **locale_long = g_strsplit_set(locale, ".", 2);
+  if(g_strv_length(locale_long) >= 1)
+    {
+      gchar *result = g_strdup(locale_long[0]);
+      g_strfreev(locale_long);
+      return result;
+    }
+  g_strfreev(locale_long);
+
+  // We found no '.', this is already a short version
+  return ( g_strdup(locale) );
+}
+
+/**
+ * Given the locale translated name, return the locale name
+ * e.g In the French local, gc_locale_get_locale("Français") returns "fr_FR.UTF8"
+ * If not found, return NULL
+ * The result must not be freed.
+ */
+const gchar*
+gc_locale_get_locale(const gchar *name)
+{
+  guint i = 0;
+
+  if ( !name )
+    return NULL;
+
+  while(linguas[i] != NULL)
+    {
+      if( !strncmp(name, gettext(linguas[i+1]), strlen(name)) )
+	 return( linguas[i] );
+
+      i=i+2;
+    }
+  // Oups this locale is not in the table.
+  return( NULL );
 }
 
 /*-------------------------------------------------------------------------------*/
@@ -528,7 +610,7 @@ display_previous_next(guint x_start, guint y_start,
 		    y_start - pixmap_width/2);
 
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   eventname_previous);
   gc_item_focus_init(item, NULL);
 
@@ -542,7 +624,7 @@ display_previous_next(guint x_start, guint y_start,
 		    y_start - pixmap_width/2);
 
   g_signal_connect(item, "button_press_event",
-		   (GtkSignalFunc) item_event_ok,
+		   (GCallback) item_event_ok,
 		   eventname_next);
   gc_item_focus_init(item, NULL);
 }
