@@ -70,8 +70,6 @@ gchar * exec_prefix = NULL;
 //static gint pause_board_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
 static void map_cb  (GtkWidget *widget, gpointer data);
-static gboolean _realize_callback (GtkWidget *widget, GdkEventExpose *event,
-				   gpointer data);
 static gint board_widget_key_press_callback (GtkWidget   *widget,
 					    GdkEventKey *event,
 					    gpointer     client_data);
@@ -146,10 +144,9 @@ static gchar *popt_server          = NULL;
 static gint  *popt_web_only        = NULL;
 static gchar *popt_cache_dir       = NULL;
 static gchar *popt_drag_mode       = NULL;
-static gchar *sugarBundleId        = NULL;
-static gchar *sugarActivityId      = NULL;
 static gint popt_sugar_look        = FALSE;
 static gint popt_no_zoom           = FALSE;
+static gint popt_test              = FALSE;
 static gdouble popt_timing_base    = 1.0;
 static gdouble popt_timing_mult    = 1.0;
 
@@ -256,23 +253,20 @@ static GOptionEntry options[] = {
   {"nolockcheck", '\0', 0, G_OPTION_ARG_NONE, &popt_nolockcheck,
    N_("Do not avoid the execution of multiple instances of GCompris."), NULL},
 
-  {"sugarBundleId", '\0', 0, G_OPTION_ARG_STRING, &sugarBundleId,
-   "Sugar Bundle Id", NULL},
-
-  {"sugarActivityId", '\0', 0, G_OPTION_ARG_STRING, &sugarActivityId,
-   "Sugar Activity Id", NULL},
-
   {"sugar",'\0', 0, G_OPTION_ARG_NONE, &popt_sugar_look,
    ("Use Sugar DE look&feel"), NULL},
 
   {"no-zoom",'\0', 0, G_OPTION_ARG_NONE, &popt_no_zoom,
-   ("Disable maximization zoom"), NULL},
+   N_("Disable maximization zoom"), NULL},
 
   {"timing-base",'\0', 0, G_OPTION_ARG_DOUBLE, &popt_timing_base,
-   ("Increase activiites' timeout delays; useful values > 1.0; 1.0 to not change hardcoded value"), NULL},
+   N_("Increase activities' timeout delays; useful values > 1.0; 1.0 to not change hardcoded value"), NULL},
 
   {"timing-mult",'\0', 0, G_OPTION_ARG_DOUBLE, &popt_timing_mult,
-   ("How activiites' timeout delays are growing for several actors; useful values < 1.0; 1.0 to not change hardcoded value"), NULL},
+   N_("How activities' timeout delays are growing for several actors; useful values < 1.0; 1.0 to not change hardcoded value"), NULL},
+
+  {"test",'\0', 0, G_OPTION_ARG_NONE, &popt_test,
+   N_("For test purpose, run in a loop all the activities"), NULL},
 
   { NULL }
 };
@@ -328,6 +322,21 @@ board_widget_key_press_callback (GtkWidget   *widget,
 {
   int kv = event->keyval;
 
+  if(event->state & GDK_CONTROL_MASK && ((event->keyval == GDK_b)
+					 || (event->keyval == GDK_B))) {
+    if(properties->bar_hidden){
+      g_message("Restoring the control bar\n");
+      properties->bar_hidden=FALSE;
+      gc_bar_hide(properties->bar_hidden);
+    }
+    else{
+      g_message("Hidding the control bar\n");
+      properties->bar_hidden=TRUE;
+      gc_bar_hide(properties->bar_hidden);
+    };
+    goo_canvas_update(GOO_CANVAS(canvas));
+    return TRUE;
+  }
   if(event->state & GDK_CONTROL_MASK && ((event->keyval == GDK_r)
 					 || (event->keyval == GDK_R))) {
     g_message("Refreshing the canvas\n");
@@ -478,12 +487,44 @@ void gc_cursor_hide()
 
   bp = gdk_bitmap_create_from_data(NULL , in_cursor , 1, 1);
   cursor = gdk_cursor_new_from_pixmap(bp , bp ,
-				      &color , &color ,
-				      1 , 1);
+                                      &color , &color ,
+                                      1 , 1);
   gdk_window_set_cursor(window->window , cursor);
   gdk_cursor_unref(cursor);
 }
 
+
+#if 0
+  // READY FOR GTK 3
+void gc_cursor_hide()
+{
+
+  GdkCursor *cursor;
+  cairo_surface_t *s;
+  GdkPixbuf *pixbuf;
+  cairo_t *cr;
+
+  s = cairo_image_surface_create (CAIRO_FORMAT_A1, 1, 1);
+  cr = cairo_create (s);
+  cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 1.0);
+  cairo_rectangle(cr, 0, 0, 1, 1);
+  cairo_fill(cr);
+  cairo_destroy(cr);
+
+  pixbuf = gdk_pixbuf_get_from_surface (s,
+					0, 0,
+					1, 1);
+  cairo_surface_destroy (s);
+
+  cursor = gdk_cursor_new_from_pixbuf (NULL, pixbuf, 0, 0);
+
+  g_object_unref (pixbuf);
+
+  gdk_window_set_cursor(window->window , cursor);
+  gdk_cursor_unref(cursor);
+}
+#endif
+
 void gc_cursor_set(guint gdk_cursor_type)
 {
   GdkCursor *cursor = NULL;
@@ -499,7 +540,7 @@ void gc_cursor_set(guint gdk_cursor_type)
   if (gdk_cursor_type < GCOMPRIS_FIRST_CUSTOM_CURSOR) {
     cursor = gdk_cursor_new(gdk_cursor_type);
     gdk_window_set_cursor (window->window, cursor);
-    gdk_cursor_destroy(cursor);
+    gdk_cursor_unref(cursor);
   } else { // we use a custom cursor
     GdkPixbuf *cursor_pixbuf = NULL;
 
@@ -683,34 +724,6 @@ gc_set_default_background(GooCanvasItem *parent)
 			  "#BACKGROUND");
 }
 
-static gboolean
-_realize_callback (GtkWidget *widget, GdkEventExpose *event, gpointer data)
-{
-#ifdef USE_SUGAR
-  Window xwindow = GDK_WINDOW_XWINDOW(window->window);
-  /*
-   * Sugar requires properties to be set before the windows is realized
-   */
-  if (sugarBundleId)
-    XChangeProperty(GDK_DISPLAY(),
-		    xwindow,
-		    XInternAtom(GDK_DISPLAY(), "_SUGAR_BUNDLE_ID", 0),
-		    XInternAtom(GDK_DISPLAY(), "STRING", 0), 8,
-		    PropModeReplace,
-		    (unsigned char *) sugarBundleId, strlen(sugarBundleId));
-
-  if (sugarActivityId)
-    XChangeProperty(GDK_DISPLAY(),
-		    xwindow,
-		    XInternAtom(GDK_DISPLAY(), "_SUGAR_ACTIVITY_ID", 0),
-		    XInternAtom(GDK_DISPLAY(), "STRING", 0), 8,
-		    PropModeReplace,
-		    (unsigned char *) sugarActivityId, strlen(sugarActivityId));
-#endif
-
-  return FALSE;
-}
-
 static void
 init_workspace()
 {
@@ -739,8 +752,8 @@ init_workspace()
   GtkWidget *quit_item;
   quit_item = gtk_menu_item_new();
   ige_mac_menu_set_quit_menu_item(GTK_MENU_ITEM (quit_item));
-  gtk_signal_connect(GTK_OBJECT (quit_item),
-		     "activate", GTK_SIGNAL_FUNC (quit_cb), NULL);
+  g_signal_connect(GTK_OBJECT (quit_item),
+		   "activate", G_CALLBACK (quit_cb), NULL);
   gtk_widget_show (quit_item);
 
 #endif
@@ -832,15 +845,13 @@ static void setup_window ()
 
   gtk_window_set_default_size(GTK_WINDOW(window), BOARDWIDTH, BOARDHEIGHT);
   gtk_window_set_wmclass(GTK_WINDOW(window), "gcompris", "GCompris");
-  g_signal_connect (GTK_OBJECT (window), "realize",
-		    G_CALLBACK (_realize_callback), NULL);
   gtk_widget_realize (window);
 
-  gtk_signal_connect (GTK_OBJECT (window), "delete_event",
-		      GTK_SIGNAL_FUNC (quit_cb), NULL);
+  g_signal_connect (GTK_OBJECT (window), "delete_event",
+		    G_CALLBACK (quit_cb), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (window), "map_event",
-		      GTK_SIGNAL_FUNC (map_cb), NULL);
+  g_signal_connect (GTK_OBJECT (window), "map_event",
+		    G_CALLBACK (map_cb), NULL);
 
   // Set the cursor
   if (properties->nocursor)
@@ -859,17 +870,17 @@ static void setup_window ()
 		NULL);
 
 
-  gtk_signal_connect_after (GTK_OBJECT (window), "key_press_event",
-			    GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
+  g_signal_connect_after (GTK_OBJECT (window), "key_press_event",
+			  (GCallback) board_widget_key_press_callback, 0);
   g_signal_connect_after (canvas,
 			  "key_press_event",
-			  GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
+			  (GCallback) board_widget_key_press_callback, 0);
 
   gc_im_init(window);
 
   init_workspace();
 
-  GTK_WIDGET_SET_FLAGS (canvas, GTK_CAN_FOCUS);
+  gtk_widget_set_can_focus(canvas, TRUE);
   gtk_widget_grab_focus (canvas);
 
 }
@@ -921,9 +932,9 @@ display_activation_dialog()
 			   100.0,
 			   30.0,
 			   NULL);
-  gtk_signal_connect(GTK_OBJECT(widget_activation_entry), "activate",
-		     GTK_SIGNAL_FUNC(activation_enter_callback),
-		     NULL);
+  g_signal_connect(GTK_OBJECT(widget_activation_entry), "activate",
+		   GTK_SIGNAL_FUNC(activation_enter_callback),
+		   NULL);
 
   char *msg = g_strdup_printf( \
       _("GCompris is free software released under the GPL License. "
@@ -1249,7 +1260,7 @@ static void map_cb (GtkWidget *widget, gpointer data)
 	gchar *tmpstr= g_strdup_printf("Couldn't find the board menu %s, or plugin execution error", properties->root_menu);
 	gc_dialog(tmpstr, NULL);
 	g_free(tmpstr);
-      } else if(!gc_board_check_file(board_to_start)) {
+      } else if(!gc_board_check_file(board_to_start) || gc_board_is_demo_only(board_to_start) ) {
 	gchar *tmpstr= g_strdup_printf("Couldn't find the board menu, or plugin execution error");
 	gc_dialog(tmpstr, NULL);
 	g_free(tmpstr);
@@ -1375,14 +1386,21 @@ char *gc_locale_get_user_default()
 
 /*
  * This set the locale for which text must be displayed
+ * If locale is NULL, "" or "NULL" then locale is set to the user's default locale
+ * if any or the user's system locale instead.
  *
  */
 void
-gc_locale_set(gchar *locale)
+gc_locale_set(const gchar *locale)
 {
 
-  if(!locale)
-    return;
+  if(!locale || locale[0] == '\0' || (g_strcmp0(locale, "NULL") == 0) )
+    {
+      if ( properties->locale && properties->locale[0] != '\0')
+	locale = properties->locale;
+      else
+	locale = gc_locale_get_user_default();
+    }
 
   g_message("gc_locale_set '%s'\n", locale);
   if(gc_locale != NULL)
@@ -1483,7 +1501,9 @@ single_instance_check()
 
 	  if(current_time.tv_sec - seconds < GC_LOCK_LIMIT)
 	    {
-	      printf(_("GCompris won't start because the lock file is less than %d seconds old.\n"),
+	      printf(ngettext("GCompris won't start because the lock file is less than %d second old.\n",
+			      "GCompris won't start because the lock file is less than %d seconds old.\n",
+			      GC_LOCK_LIMIT),
 		     GC_LOCK_LIMIT);
 	      printf(_("The lock file is: %s\n"),
 		     lock_file);
@@ -1505,6 +1525,68 @@ single_instance_check()
   // Do not free lock_file, the unlink needs it
 }
 
+gboolean test_board_end(gpointer data);
+
+gboolean test_board_start(gpointer data) {
+  GList *full_list = (GList *) data;
+  GcomprisBoard *board = (GcomprisBoard*)full_list->data;
+  printf("Testing %s/%s : %s (%s) \n", board->section, board->name, board->title, board->description );
+  gc_board_run_next(board);
+
+  g_timeout_add(600, test_board_end, full_list);
+  return FALSE;
+}
+gboolean test_board_end(gpointer data) {
+   GList *full_list = (GList *) data;
+   gc_close_all_dialog();
+
+  gc_board_stop();
+  if (full_list->next) {
+    full_list = full_list->next;
+    g_timeout_add(600, test_board_start, full_list);
+  } else {
+    printf("TEST DONE\n");
+  }
+  return FALSE;
+}
+
+void gc_test() {
+  gc_db_init(FALSE /* ENABLE DATABASE */);
+  gc_board_init();
+  gc_menu_load();
+
+  // Create the list of all the activity in full_list
+  GList *full_list = NULL;
+
+  GList *list = NULL;
+  GList *menulist = NULL;
+  GList *menu_todo = NULL;
+
+  menu_todo = g_list_append(menu_todo,g_strdup("/"));
+
+  while ( menu_todo != NULL) {
+    menulist = gc_menu_getlist(menu_todo->data);
+    g_free(menu_todo->data);
+    menu_todo = menu_todo->next;
+
+    for(list = menulist; list != NULL; list = list->next) {
+      GcomprisBoard *board = list->data;
+
+      if (board){
+	if (strcmp(board->type,"menu")==0)
+	  menu_todo = g_list_prepend(menu_todo, g_strdup_printf("%s/%s",board->section, board->name));
+	else {
+	  full_list = g_list_append(full_list, board);
+	}
+      }
+    }
+  }
+
+  // Start the test in a few seconds to be sure everything is loaded
+  g_timeout_add(5000, test_board_start, full_list);
+
+}
+
 /*****************************************
  * Main
  *
@@ -1980,10 +2062,9 @@ main (int argc, char *argv[])
 	gc_sound_play_ogg("voices/$LOCALE/misc/welcome.ogg", NULL);
     }
 
-#ifndef WIN32
-  if (sugarActivityId)
-    gc_dbus_init(sugarActivityId);
-#endif
+  if (popt_test) {
+    gc_test();
+  }
 
   gtk_main ();
 
