@@ -145,7 +145,7 @@ start_board (GcomprisBoard *agcomprisBoard)
   gchar *filename = NULL;
   GHashTable *config = gc_db_get_board_conf();
 
-  gc_locale_change(g_hash_table_lookup( config, "locale"));
+  gc_locale_set(g_hash_table_lookup( config, "locale"));
 
   g_hash_table_destroy(config);
 
@@ -192,7 +192,7 @@ end_board ()
       destroy_board_list();
     }
 
-  gc_locale_reset();
+  gc_locale_set( NULL );
 
   gcomprisBoard = NULL;
 }
@@ -349,7 +349,7 @@ imageid_create_item(GooCanvasItem *parent)
 		      "button", button);
 
       g_signal_connect(button, "button_press_event",
-		       (GtkSignalFunc) item_event,
+		       (GCallback) item_event,
 		       GINT_TO_POINTER(i));
 
       item = goo_canvas_text_new (group,
@@ -363,7 +363,7 @@ imageid_create_item(GooCanvasItem *parent)
 				  NULL);
 
       g_signal_connect(item, "button_press_event",
-		       (GtkSignalFunc) item_event,
+		       (GCallback) item_event,
 		       GINT_TO_POINTER(i));
 
       item = goo_canvas_text_new (group,
@@ -377,7 +377,7 @@ imageid_create_item(GooCanvasItem *parent)
 				  NULL);
 
       g_signal_connect(item, "button_press_event",
-		       (GtkSignalFunc) item_event,
+		       (GCallback) item_event,
 		       GINT_TO_POINTER(i));
 
       yp +=  button_pixmap_height + vertical_separation;
@@ -662,12 +662,12 @@ static void save_table (gpointer key,
 			    (gchar *) value);
 }
 
-static GcomprisConfCallback conf_ok(GHashTable *table)
+static gboolean conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
       pause_board(FALSE);
-    return NULL;
+    return TRUE;
   }
 
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
@@ -696,7 +696,7 @@ static GcomprisConfCallback conf_ok(GHashTable *table)
   board_conf = NULL;
   profile_conf = NULL;
 
-  return NULL;
+  return TRUE;
 }
 
 static void
@@ -714,7 +714,7 @@ config_start(GcomprisBoard *agcomprisBoard,
 				 aProfile ? aProfile->name : "");
   GcomprisBoardConf *bconf;
   bconf = gc_board_config_window_display( label,
-				 (GcomprisConfCallback )conf_ok);
+				 conf_ok);
 
   g_free(label);
 
