@@ -154,7 +154,7 @@ start_board (GcomprisBoard *agcomprisBoard)
 {
   GHashTable *config = gc_db_get_board_conf();
 
-  gc_locale_change(g_hash_table_lookup( config, "locale"));
+  gc_locale_set(g_hash_table_lookup( config, "locale"));
 
   gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
 
@@ -193,7 +193,7 @@ static void end_board ()
       board_list = NULL;
     }
 
-  gc_locale_reset();
+  gc_locale_set( NULL );
 
   gcomprisBoard_missing = NULL;
 }
@@ -366,7 +366,7 @@ missing_letter_create_item(GooCanvasItem *parent)
 			"solution", GINT_TO_POINTER(board->solution));
 
       g_signal_connect(button, "button_press_event",
-		       (GtkSignalFunc) item_event,
+		       (GCallback) item_event,
 		       GINT_TO_POINTER(i));
 
       item = goo_canvas_text_new (group,
@@ -380,7 +380,7 @@ missing_letter_create_item(GooCanvasItem *parent)
 				  NULL);
 
       g_signal_connect(item, "button_press_event",
-		       (GtkSignalFunc) item_event,
+		       (GCallback) item_event,
 		       GINT_TO_POINTER(i));
 
       item = goo_canvas_text_new (group,
@@ -394,7 +394,7 @@ missing_letter_create_item(GooCanvasItem *parent)
 				  NULL);
 
       g_signal_connect(item, "button_press_event",
-		       (GtkSignalFunc) item_event,
+		       (GCallback) item_event,
 		       GINT_TO_POINTER(i));
 
       yOffset += gdk_pixbuf_get_height(button_pixmap) + vertical_separation;
@@ -717,13 +717,13 @@ static void save_table (gpointer key,
 			 (gchar *) value);
 }
 
-static GcomprisConfCallback
+static gboolean
 conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard_missing)
       pause_board(FALSE);
-    return NULL;
+    return TRUE;
   }
 
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
@@ -763,7 +763,7 @@ conf_ok(GHashTable *table)
   profile_conf = NULL;
   pause_board(FALSE);
 
-  return NULL;
+  return TRUE;
 }
 
 static void
@@ -786,7 +786,7 @@ config_start(GcomprisBoard *agcomprisBoard,
 				 aProfile ? aProfile->name : "");
   GcomprisBoardConf *bconf;
   bconf = gc_board_config_window_display( label,
-				 (GcomprisConfCallback )conf_ok);
+				 conf_ok);
 
   g_free(label);
 
