@@ -641,11 +641,11 @@ scale_list_add_weight(GooCanvasItem *group,
 
   gc_item_focus_init(new_item->item, NULL);
   g_signal_connect(new_item->item, "button_press_event",
-		   (GtkSignalFunc)gc_drag_event, new_item);
+		   (GCallback)gc_drag_event, new_item);
   g_signal_connect(new_item->item, "button_release_event",
-		   (GtkSignalFunc)gc_drag_event, new_item);
+		   (GCallback)gc_drag_event, new_item);
   g_signal_connect(new_item->item, "button_press_event",
-  		   (GtkSignalFunc) scale_item_event, new_item);
+  		   (GCallback) scale_item_event, new_item);
 
   item_list = g_list_append(item_list, new_item);
   return new_item;
@@ -1004,7 +1004,7 @@ scale_next_level()
   /* display some hint */
   if(gcomprisBoard->level > 2 || board_mode == MODE_WEIGHT)
     goo_canvas_text_new(boardRootItem,
-			_("Take care, you can drop masses on both sides of the scale."),
+			_("Take care, you can drop weights on both sides of the scale."),
 			BOARDWIDTH/2,
 			ITEM_Y_MIN - 20,
 			-1,
@@ -1107,12 +1107,13 @@ static void save_table (gpointer key,
 			 (gchar *) value);
 }
 
-static void conf_ok(GHashTable *table)
+static gboolean
+conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
       pause_board(FALSE);
-    return;
+    return TRUE;
   }
 
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
@@ -1144,7 +1145,7 @@ static void conf_ok(GHashTable *table)
 
   board_conf = NULL;
   profile_conf = NULL;
-
+  return TRUE;
 }
 
 static void
@@ -1163,7 +1164,7 @@ config_start(GcomprisBoard *agcomprisBoard,
 
   GcomprisBoardConf *bconf;
   bconf = gc_board_config_window_display( label,
-					  (GcomprisConfCallback )conf_ok);
+					  conf_ok);
 
   g_free(label);
 
