@@ -162,10 +162,10 @@ static void pause_board (gboolean pause)
     {
       if(!drop_items_id) {
 	drop_items_id = g_timeout_add (0,
-				       (GtkFunction) wordsgame_drop_items, NULL);
+				       (GSourceFunc) wordsgame_drop_items, NULL);
       }
       if(!dummy_id) {
-	dummy_id = g_timeout_add (10, (GtkFunction) wordsgame_move_items, NULL);
+	dummy_id = g_timeout_add (10, (GSourceFunc) wordsgame_move_items, NULL);
       }
     }
 }
@@ -180,7 +180,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard=agcomprisBoard;
 
       GHashTable *config = gc_db_get_board_conf();
-      gc_locale_change(g_hash_table_lookup( config, "locale"));
+      gc_locale_set(g_hash_table_lookup( config, "locale"));
 
       gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
       if (up_init_str && (strcmp(up_init_str, "True")==0))
@@ -247,7 +247,7 @@ end_board ()
       }
     }
 
-  gc_locale_reset();
+  gc_locale_set( NULL );
 }
 
 static void
@@ -511,7 +511,7 @@ static void wordsgame_move_item(LettersItem *item)
     g_ptr_array_add (items2del, item);
     g_static_rw_lock_writer_unlock (&items2del_lock);
 
-    g_timeout_add (100,(GtkFunction) wordsgame_destroy_items, items2del);
+    g_timeout_add (100,(GSourceFunc) wordsgame_destroy_items, items2del);
 
     player_loose();
   }
@@ -536,7 +536,7 @@ static gint wordsgame_move_items (GtkWidget *widget, gpointer data)
       wordsgame_move_item(item);
     }
   dummy_id = g_timeout_add (gc_timing (speed, items->len),
-          (GtkFunction) wordsgame_move_items, NULL);
+          (GSourceFunc) wordsgame_move_items, NULL);
   return (FALSE);
 }
 
@@ -652,7 +652,7 @@ static GooCanvasItem *wordsgame_create_item(GooCanvasItem *parent)
 			 -1,
 			 direction_anchor,
 			 "font", gc_skin_font_board_huge_bold,
-			 "fill_color_rgba", 0xba00ffff,
+			 "fill_color_rgba", 0xffffffff,
 			 NULL);
 
   item->overwriteItem = \
@@ -663,7 +663,7 @@ static GooCanvasItem *wordsgame_create_item(GooCanvasItem *parent)
 			 -1,
 			 direction_anchor,
 			 "font", gc_skin_font_board_huge_bold,
-			 "fill-color_rgba", 0x33c033ff,
+			 "fill-color_rgba", 0x000000ff,
 			 NULL);
 
   /*set right x position */
@@ -711,7 +711,7 @@ static gint wordsgame_drop_items (GtkWidget *widget, gpointer data)
   gc_sound_play_ogg ("sounds/level.wav", NULL);
   wordsgame_add_new_item();
   g_source_remove(drop_items_id);
-  drop_items_id = g_timeout_add (fallSpeed,(GtkFunction) wordsgame_drop_items, NULL);
+  drop_items_id = g_timeout_add (fallSpeed,(GSourceFunc) wordsgame_drop_items, NULL);
 
   return (FALSE);
 }
@@ -736,7 +736,7 @@ static void player_win(LettersItem *item)
   g_static_rw_lock_writer_unlock (&items2del_lock);
 
   g_object_set (item->rootitem, "visibility", GOO_CANVAS_ITEM_INVISIBLE, NULL);
-  g_timeout_add (500,(GtkFunction) wordsgame_destroy_items, items2del);
+  g_timeout_add (500,(GSourceFunc) wordsgame_destroy_items, items2del);
 
 
   if(gcomprisBoard->sublevel > gcomprisBoard->number_of_sublevel)
@@ -774,7 +774,7 @@ static void player_win(LettersItem *item)
 
           if(!drop_items_id) {
             drop_items_id = g_timeout_add (0,
-					   (GtkFunction) wordsgame_drop_items,
+					   (GSourceFunc) wordsgame_drop_items,
 					   NULL);
           }
 
@@ -809,12 +809,13 @@ static void save_table (gpointer key,
 			    (gchar *) value);
 }
 
-static void conf_ok(GHashTable *table)
+static gboolean
+conf_ok(GHashTable *table)
 {
   if (!table){
     if (gcomprisBoard)
       pause_board(FALSE);
-    return;
+    return TRUE;
   }
 
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
@@ -848,6 +849,7 @@ static void conf_ok(GHashTable *table)
 
   board_conf = NULL;
   profile_conf = NULL;
+  return TRUE;
 }
 
 static void
@@ -866,7 +868,7 @@ wordsgame_config_start(GcomprisBoard *agcomprisBoard,
 				 aProfile? aProfile->name: "");
 
   conf = gc_board_config_window_display( label,
-				 (GcomprisConfCallback )conf_ok);
+					 conf_ok);
 
   g_free(label);
 
